import React, { useState, useEffect } from 'react';
import { Card, Form, Input, Button, Select, message } from 'antd';
import ProCard from '@ant-design/pro-card';
import { getOrderDetail } from '@/services/order'
import { getMachineryList } from '@/services/machinery';
import { history } from 'umi';
import { getUserList } from '@/services/user';
import { addDispatch } from '@/services/dispatch';

const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const { Option } = Select;
const goBack = () => {
  history.goBack();
};
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [order, setOrder] = useState();
  const [loading, setLoading] = useState(false);
  const [machineryList, setMachineryList] = useState([]);
  const [userList, setUserList] = useState([])
  const submit = () => {
    if (!order.machineryId) {
      message.warning('请选择调度的农机');
      return
    }
    if (!order.workerId) {
      message.warning('请选择农机手');
      return
    }
    setLoading(true)
    addDispatch(order).then(res => {
      message.success('调度成功');
      setLoading(false);
      goBack()
    }).catch((err) => {
      setLoading(false);
      message.error(err.message || err);
    });
  };
  const changeMachinery = (e) => {
    setOrder({ ...order, machineryId: e })
  }
  const changeUser = (e) => {
    setOrder({ ...order, workerId: e })
  }
  useEffect(() => {
    getOrderDetail(id).then((res) => {
      setOrder(res)
      getMachineryList({ orgId: res.orgId, pageSize: 999 }).then((res2) => {
        setMachineryList(res2.records)
      })
      getUserList({ org_id: res.orgId, pageSize: 999 }).then(res3 => {
        setUserList(res3.records)
      })
    })
  }, [])
  return (
    <Card>
      <ProCard tabs={{ type: 'card' }}>
        <ProCard.TabPane key={1} tab="订单调度">
          <Form {...formItemLayout}>
            <FormItem label="客户姓名">
              {order?.personName}
            </FormItem>
            <FormItem label="联系电话">
              {order?.phone}
            </FormItem>
            <FormItem label="预约地址">
              {order?.address}
            </FormItem>
            <FormItem label="预约时间">
              {order?.appointmentDate}
            </FormItem>
            <FormItem label="机构名">
              {order?.orgName}
            </FormItem>
            <FormItem label="农机类型">
              {order?.typeName}
            </FormItem>
            <FormItem label="农机">
              <Select placeholder="请选择" value={order?.machineryId} onChange={changeMachinery} allowClear style={{ width: '350px' }}>
                {machineryList.map((item) => (
                  <Option value={item.machineryId} key={item.machineryId}>
                    {item.name}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem label="农机手">
              <Select placeholder="请选择" value={order?.workerId} onChange={changeUser} allowClear style={{ width: '350px' }}>
                {userList.map((item) => (
                  <Option value={item.userId} key={item.userId}>
                    {item.userName}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem label=" " colon={false}>
              <Button type="default" onClick={() => goBack()}>
                返回
              </Button>
              <Button type="primary" loading={loading} onClick={submit} style={{ marginLeft: '4em' }}>
                保存
              </Button>
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
